![](https://gitlab.com/joajfreitas/bookmarks/badges/master/pipeline.svg)

# Marcador

Minimal bookmark manager

## Install

	$ pip install marcador

## Usage

CLI interface
	
	$ marcador --help

	Usage: marcador [OPTIONS] COMMAND [ARGS]...
	
	Options:
	  --version
	  --help     Show this message and exit.
	
	Commands:
	  add
	  bookmarks
	  delete
	  rofi
	  server


### Rofi interface

	$ marcador rofi

## Thanks
This project is heavily inspired by [buku](https://github.com/jarun/Buku)

## Screenshots
![bookmarks screenshot](https://raw.githubusercontent.com/joajfreitas/marcador/master/showcase_pretty.png)
